==> campsite-2.4.1.tbz: campsite/www-common/html/priv/lang/cz/templates.php <==
<?php
regGS("The template $1 is in use and can not be deleted.", "");
regGS("The folder could not be deleted.", "Složka nemohla být smazána");
regGS("The directory must be empty", "");
regGS("Create new folder", "Vytvořit novou složku");
regGS("Upload template", "Obnovit šablonu");
regGS("Creating new folder", "Vytváření nové složky");
regGS("You do not have the right to create new folders.", "Nemáte právo vytvářet nové složky");
regGS("The folder $1 could not be created", "Složka $1 nemohla být vytvořena");
regGS("A file or folder having the name $1 already exists", "");
regGS("You do not have the right to delete templates.", "Nemáte právo mazat šablony");
regGS("Are you sure you want to delete the folder $1 from $2?", "Určitě chcete smazat složku $1 z $2?");
regGS("Are you sure you want to delete the template $1 from folder $2?", "Určitě chcete smazat šablonu $1 ze složky $2?");
regGS("Deleting template", "Mazání šablony");
regGS("Deleting folder", "Mazání složky");
regGS("The folder has been deleted.", "Složka byla smazána");
regGS("The template has been deleted.", "Šablona byla smazána");
regGS("The template could not be deleted.", "Šablona nemohla být smazána");
regGS("Template $1 was deleted", "");
regGS("Delete folder", "Smazat složku");
regGS("Folders", "Složky");
regGS("No folders.", "Žádné složky");
regGS("Files", "Soubory");
regGS("No templates.", "Žádné šablony");
regGS("Uploading template", "Nahrát šablonu");
regGS("File", "Soubor");
regGS("Create new template", "Vytvořit novou šablonu");
regGS("Creating new template", "Vytváření nové šablony");
regGS("Duplicate template", "Duplikovat šablonu");
regGS("Edit template", "Editovat šablonu");
regGS("Save", "Uložit");
regGS("The template $1 has been created.", "Šablona $1 byla vytvořena");
regGS("Do you want to edit the template ?", "Chcete editovat šablonu?");
regGS("The template $1 could not be created.", "Šablona $1 nemohla být vytvořena");
regGS("Template $1 was changed", "Šablona $1 byla změněna");
regGS("New template $1 was created", "Byla vytvořena nová šablona $1");
regGS("Template $1 was duplicated into $2", "Šablona $1 byla duplikována do $2");
regGS("Template charset", "Kódová stránka šablony");
regGS("Select a language/character set", "Vyberte jazyk/kódové stránky");
regGS("All languages", "Všechny jazyky");
regGS("You do not have the right to modify templates.", "");
regGS("Invalid template file $1", "");
?>

==> campsite-2.6.1.tbz: campsite/www-common/html/priv/lang/cz/templates.php <==
<?php 
regGS("Template ID:", "");
regGS("Template ID", "");
regGS("Template $1 no longer exists!", "");
regGS("New template $1 created", "");
regGS("If the file you specified is a text file, you can convert its character set using the dropdown below.", "");
regGS("Directory $1 was deleted", "");
regGS("Directory $1 created.", "");
regGS("You must select a file to upload.", "");
regGS("You can only replace a file with a file of the same type.  The original file is of type \"$1\", and the file you uploaded was of type \"$2\".", "");
regGS("Unable to save the file '$1' to the path '$2'.", "");
regGS("Replace file:", "");
regGS("Replace", "");
regGS("File \"$1\" uploaded.", "");
regGS("File \"$1\" replaced.", "");
regGS("The folder name can't be '..' or '.'", "");
regGS("The template '$1' was saved successfully.", "");
regGS("The template $1 is in use and can not be deleted.", "");
regGS("Create new folder", "Vytvořit novou složku");
regGS("Upload template", "Obnovit šablonu");
regGS("You do not have the right to create new folders.", "Nemáte právo vytvářet nové složky");
regGS("A file or folder having the name $1 already exists", "");
regGS("You do not have the right to delete templates.", "Nemáte právo mazat šablony");
regGS("Are you sure you want to delete the folder $1 from $2?", "Určitě chcete smazat složku $1 z $2?");
regGS("Are you sure you want to delete the template $1 from folder $2?", "Určitě chcete smazat šablonu $1 ze složky $2?");
regGS("The folder has been deleted.", "Složka byla smazána");
regGS("The template has been deleted.", "Šablona byla smazána");
regGS("The template could not be deleted.", "Šablona nemohla být smazána");
regGS("Template $1 was deleted", "");
regGS("Delete folder", "Smazat složku");
regGS("Folders", "Složky");
regGS("No folders.", "Žádné složky");
regGS("Files", "Soubory");
regGS("No templates.", "Žádné šablony");
regGS("File", "Soubor");
regGS("Create new template", "Vytvořit novou šablonu");
regGS("Duplicate template", "Duplikovat šablonu");
regGS("Edit template", "Editovat šablonu");
regGS("Save", "Uložit");
regGS("The template $1 could not be created.", "Šablona $1 nemohla být vytvořena");
regGS("Template $1 was changed", "Šablona $1 byla změněna");
regGS("Template $1 was duplicated into $2", "Šablona $1 byla duplikována do $2");
regGS("Template charset", "Kódová stránka šablony");
regGS("Select a language/character set", "Vyberte jazyk/kódové stránky");
regGS("All languages", "Všechny jazyky");
regGS("You do not have the right to modify templates.", "");
regGS("Invalid template file $1", "");
?>
